<?php

class noticias {

private $nti_id;
private $nti_titulo;
private $nti_descricao;
private $nti_imagem;
private $nti_categoria;

public function getnti_id(){
return $this->nti_id;
}

public function setnti_id($nti_id){
$this->nti_id = $nti_id;
}

public function getnti_titulo(){
return $this->nti_titulo;
}

public function setnti_titulo($nti_titulo){
$this->nti_titulo = $nti_titulo;
}

public function getnti_descricao(){
return $this->nti_descricao;
}

public function setnti_descricao($nti_descricao){
$this->nti_descricao = $nti_descricao;
}

public function getnti_imagem(){
return $this->nti_imagem;
}

public function setnti_imagem($nti_imagem){
$this->nti_imagem = $nti_imagem;
}

public function getnti_categoria(){
return $this->nti_categoria;
}

public function setnti_categoria($nti_categoria){
$this->nti_categoria = $nti_categoria;
}

}

?>